#!/usr/bin/env python
import os
import tempfile

from ltpylib import files, procs


def diff_git(
  initial: str,
  updated: str,
  add_suffix: str = None,
  context_lines: int = None,
  color: str = "always",
) -> str:
  suffix_prefix = ("." + add_suffix) if add_suffix else ""

  ifd, initial_temp_file = tempfile.mkstemp(suffix=suffix_prefix + ".initial")
  ufd, updated_temp_file = tempfile.mkstemp(suffix=suffix_prefix + ".updated")
  os.close(ifd)
  os.close(ufd)

  files.write_file(initial_temp_file, initial)
  files.write_file(updated_temp_file, updated)

  try:
    command = [
      "git",
      "diff",
      "--no-index",
      "-w",
    ]

    if color:
      command.append("--color=%s" % color)

    if context_lines is not None:
      command.append("--unified=%s" % str(context_lines))

    command.extend([initial_temp_file, updated_temp_file])
    result = procs.run(
      command,
      check=False,
    )
    return result.stdout
  finally:
    os.remove(initial_temp_file)
    os.remove(updated_temp_file)



#!/usr/bin/env python
import semver


class LenientVersionInfo(semver.VersionInfo):

  def __init__(self, version: str):
    self.original_version: str = version

    self.version = version
    if self.version.count(".") <= 0:
      self.version = self.version + ".0.0"
    elif self.version.count(".") <= 1:
      self.version = self.version + ".0"

    parsed = semver.parse_version_info(self.version)
    semver.VersionInfo.__init__(self, parsed.major, parsed.minor, parsed.patch, parsed.prerelease, parsed.build)
